import sys
import os

sys.path.append(os.path.join(os.path.dirname(__file__)))

import EventHub.SendEvents as SendEvents

def run(env_name, client_code, account_name, events_json):
    return SendEvents.send_events('FulfillmentScheduledDelivery', env_name, client_code, account_name, events_json)

# for testing 
if sys.stdin and len(sys.argv) > 0:
    print(SendEvents.run('FulfillmentScheduledDelivery'))
    print('order.create events were sent.')





import sys, argparse, asyncio, json
import EventHub.Event as Event
import Settings.Environment as Environment

def run(event_type):
    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(send_events_using_command_line(event_type))
    loop.close()
    return result

def run_send_events(event_type, env_name, client_code, account_name, events_json):
    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    result = loop.run_until_complete(send_events(event_type, env_name, client_code, account_name, events_json))
    loop.close()
    return result

async def send_events_using_command_line(event_type):
    events = (json.loads(args.events))
    client_code = args.code
    account_name = args.account
    return await Event.run(event_type, client_code, account_name, events)

async def send_events(event_type, env_name, client_code, account_name, events_json):
    Environment.set_environment(env_name)   
    events = (json.loads(events_json))
    return await Event.run(event_type, client_code, account_name, events)


#Declare script parameters
parser = argparse.ArgumentParser()
parser.add_argument("--env", help="Sets environment. Development, Production, QA or Learn", type=str)
parser.add_argument("--code", help="Sets Storis client code", type=str)
parser.add_argument("--events", help="Sets Storis client code")
parser.add_argument("--account", help="Sets Storis Account name")

args, unknown = parser.parse_known_args()

if args.env != None:
    Environment.set_environment(args.env)


    



import json

class Response:
    def __init__(self, success, error_message):
        self.success = success
        self.error_message = error_message

    def toJSON(self):
        return json.dumps(self, default=lambda o: o.__dict__, 
            sort_keys=True, indent=4)







import sys
import os
from pathlib import Path

currentDirectory = os.getcwd()
#eventHubDirectory = currentDirectory + "\EventPublisher\EventHub"
#settingsDirectory = currentDirectory + "\EventPublisher\Settings"
eventPublisherDirectory = currentDirectory + "\EventPublisher"
#path = Path(currentDirectory) 
#absolutePath = str(path.parent.absolute())
sys.path.append(eventPublisherDirectory)
#sys.path.append(currentDirectory)
#sys.path.append(eventHubDirectory)
#sys.path.append(settingsDirectory)
#sys.path.append(absolutePath)

import EventHub.SendEvents as SendEvents

SendEvents.run_send_events('order.create', 'Development', 'fla-105-code', 'fla-105', '[{"entityId":"a"}]')
#Environment.set_environment()



import sys
import os

sys.path.append(os.path.join(os.path.dirname(__file__)))

import EventHub.SendEvents as SendEvents

def run(env_name, client_code, account_name, events_json):
    return SendEvents.send_events('OrderWrittenSale', env_name, client_code, account_name, events_json)

# for testing
if sys.stdin and len(sys.argv) > 0:
   print('Running CMD command....')
   print(SendEvents.run('OrderWrittenSale'))
   print('OrderWrittenSale events were sent.')







import sys, traceback, json, asyncio
from azure.eventhub.aio import EventHubProducerClient
from azure.eventhub import EventData
from azure.eventhub.exceptions import EventHubError
import Settings.Configuration as Configuration
from EventHub.Response import Response

@asyncio.coroutine
async def run(event_type, client_code, account_name, events):
    try:
        producer = get_producer()
        await send_event_data_batch_with_partition_key(producer, event_type, client_code, account_name, events)
        print("Events for client: " + client_code + " has been sent.")
        response = Response(True, "")
        return response.toJSON()
    except EventHubError as eh_err:
        print("Sending error: ", eh_err)
        response = Response(False, traceback.format_exc())
        return response.toJSON()
    except Exception as eh_err:
        response = Response(False, traceback.format_exc())
        return response.toJSON()

async def send_event_data_batch_with_partition_key(producer, event_type, client_code, account_name, events):
    #Specifying partition_key
    event_data_batch_with_partition_key = await producer.create_batch(partition_key=get_partition_key(event_type))

    #Add events to the batch.
    length = len(events)
    for index in range(0, length):
        event_data = create_event_data(events[index], client_code, account_name, event_type)
        event_data_batch_with_partition_key.add(event_data)
        #print(event_data)
        
    await producer.send_batch(event_data_batch_with_partition_key)

def get_producer():
    producer = EventHubProducerClient.from_connection_string(
        conn_str=get_connection_string(), 
        eventhub_name=get_eventhub_name())
    return producer

def get_connection_string():
    print(Configuration.get())
    return Configuration.get().EventHub.connection_string

def get_eventhub_name():
    return Configuration.get().EventHub.name

def get_partition_key(event_type):
    return event_type

def create_event_data(event_body, client_code, account_name, event_type):
    event_data = EventData(str(event_body))
    event_data.properties = {'event_type': event_type, 'client_code': client_code, 'account_name': account_name}
    return event_data

    





import Settings.Development, Settings.Production, Settings.Learn, Settings.Staging, Settings.Environment, Settings.Constants

def get():
    return {
        Settings.Constants.DEVELOPMENT: Settings.Development,
        Settings.Constants.PRODUCTION: Settings.Production,
        Settings.Constants.LEARN: Settings.Learn,
        Settings.Constants.QA: Settings.Staging
    }[Settings.Environment.get_environment()]
